@@ -56,10 +56,6 @@ void devOrientation::timerEvent(QTimerEvent *) {
 
     bool sent = QDBusConnection::systemBus().callWithCallback(msg, this,
                                                               SLOT(mceOrientationSlot(QString, QString, QString, int, int, int)));
-    float rx = rand() % 20 - 10;
-    float ry = rand() % 20 - 10;
-    float rz = rand() % 20 - 10;
-    emit dataProcessed(QVector3D(-rx, -ry, -rz));
 }
 
 void devOrientation::mceOrientationSlot(const QString &rotation, const QString &stand, const QString &face, int x, int y, int z) {
