@@ -75,6 +75,7 @@ Painter::Painter(QWidget *parent, ErrorHandler *errorHandler) :
     isModified = false;
     isIce = false;
     activated = false;
+    isClean = true;
 
     currentEffect = 0;
 
@@ -98,8 +99,7 @@ Painter::Painter(QWidget *parent, ErrorHandler *errorHandler) :
     createActions();
 
     connect(touchTimer, SIGNAL(timeout()), SLOT(showContextMenu()));
-    connect(acc, SIGNAL(deviceOrientationChanged(QVector3D)), SLOT(setPosition(QVector3D)));
-    connect(acc, SIGNAL(accShaking()), SLOT(clearWorkspace()));
+    connect(acc, SIGNAL(deviceOrientationChanged(QVector3D)), SLOT(setPosition(QVector3D)));   
     connect(acc, SIGNAL(accRolling()), SLOT(rollHandler()));
     connect(acc, SIGNAL(accModeDisabled()), SLOT(changeModeByShaking()));
     connect(mce, SIGNAL(sigDisplayStateChanged(QString)), SLOT(changeState(QString)));
@@ -122,6 +122,7 @@ void Painter::createImage() {
     QImage image(WIDTH, FS_HEIGHT, QImage::Format_RGB16);
     image.fill(qRgb(255, 255, 255)); // white color for background
     isModified = false;
+    isClean = true;
     setImage(image);
 }
 
@@ -132,6 +133,7 @@ bool Painter::openImage(const QString &fileName) {
         return false;
     image = image.scaled(QSize(WIDTH, FS_HEIGHT), Qt::KeepAspectRatio, Qt::SmoothTransformation);
     isModified = false;
+    isClean = false;
     setImage(image);
     return true;
 }
@@ -170,12 +172,14 @@ void Painter::mousePressEvent(QMouseEvent *e) {
                 painter.drawPoint(e->x(), e->y());
 
                 isModified = true;
+                isClean = false;
                 checkBoundaries();
             } else {
                 if(!((abs(e->x() - lastX) < m_size/5) && (abs(e->y() - lastY) < m_size/5)))
                     m_pos = e->pos();                
 
-                isModified = true;                
+                isModified = true;
+                isClean = false;
                 *theImage = filter->blurCircle(e->x(),e->y(),(int)m_size/2, theImage);
             }
 
@@ -260,6 +264,7 @@ void Painter::mouseMoveEvent(QMouseEvent *e) {
                 painter.drawLine(lastX, lastY, e->x(), e->y());
 
                 isModified = true;
+                isClean = false;
                 m_pos = e->pos();
 
                 checkBoundaries();
@@ -269,6 +274,7 @@ void Painter::mouseMoveEvent(QMouseEvent *e) {
                 if (currentEffect == NO_EFFECT)
                     *theImage = filter->blurCircle(e->x(),e->y(),(int)m_size/2, theImage);
                 isModified = true;
+                isClean = false;
             }
             update();
         }
@@ -363,6 +369,7 @@ void Painter::setPosition(QVector3D accVector3) {
     // If user touchs Finger Zone, then painting is active
     if(isPainting) {
         isModified = true;
+        isClean = false;
         if(isIce)
             *theImage = filter->blurCircle(m_pos.x(),m_pos.y(),(int)m_size/2, theImage);
         else {
