@@ -25,6 +25,7 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 #include "error_handler/errors.h"
+#include "help.h"
 
 #include <math.h>
 #include <QColor>
@@ -61,6 +62,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(painter, SIGNAL(disableAccelerometer()), SLOT(disableAccelerometer()));
     connect(painter, SIGNAL(activateAccelerometer()), SLOT(activateAccelerometer()));
     connect(this, SIGNAL(sigBgModeChanged(QString)), painter, SLOT(changeState(QString)));
+    connect(painter->acc, SIGNAL(accShaking()), this, SLOT(confirmClearing()));
 }
 
 MainWindow::~MainWindow()
@@ -68,6 +70,28 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
+void MainWindow::confirmClearing() {
+    if (!painter->isClean) {
+        QMessageBox msgBox;
+        msgBox.setText("Clearing workspace");
+        msgBox.setInformativeText("Do you want to clear workspace?");
+        msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No );
+        msgBox.setDefaultButton(QMessageBox::Yes);
+
+        int ret = msgBox.exec();
+
+        switch (ret) {
+           case QMessageBox::Yes:
+                painter->clearWorkspace();
+                break;
+           case QMessageBox::No:
+               break;
+           default:
+               break;
+        }
+    }
+}
+
 // Creates all actions for Menus and Tools panel
 void MainWindow::createActions() {
     newAct = new QAction(tr("&New"), this);
@@ -118,6 +142,9 @@ void MainWindow::createActions() {
 
     aboutAct = new QAction(tr("About program"), this);
     connect(aboutAct, SIGNAL(triggered()), SLOT(showAbout()));
+
+    helpAct = new QAction(tr("Help"), this);
+    connect(helpAct, SIGNAL(triggered()), SLOT(showHelp()));
 }
 
 // Creates menus of application
@@ -133,8 +160,14 @@ void MainWindow::createMenus() {
     modeMenu = ui->menubar->addMenu(tr("&Mode"));
     modeMenu->addAction(toggleAcc);    
 
-    aboutMenu = ui->menubar->addMenu(tr("&About"));
-    aboutMenu->addAction(aboutAct);
+    helpMenu = ui->menubar->addMenu(tr("&Help"));
+    helpMenu->addAction(aboutAct);
+    helpMenu->addAction(helpAct);
+}
+
+void MainWindow::showHelp() {
+    Help help;
+    help.exec();
 }
 
 // Shows dilog with information about application and developers
@@ -171,7 +204,7 @@ void MainWindow::open()
                                                           "Images: (*.png *.jpeg *.jpg)");
     if (!fileName.isEmpty()) {
         if (!painter->openImage(fileName)) {
-            QMessageBox::information(this, tr("Pearl"),
+            QMessageBox::information(this, tr("Liquid"),
                                      tr("Cannot load %1.").arg(fileName));
             return;
         }
@@ -192,7 +225,7 @@ void MainWindow::save() {
 
 // Shows Save As Dialog
 bool MainWindow::saveAs() {
-    const QString initialPath = QDir::currentPath() + "/untitled.png";
+    const QString initialPath = QDir::homePath() + "/MyDocs/untitled.png";
     const QString fileName = QFileDialog::getSaveFileName(this, tr("Save As"),
                                                           initialPath);
     m_fileName = fileName;
@@ -203,7 +236,7 @@ bool MainWindow::saveAs() {
     }
 }
 
-// Shows exit dialog (Save, Discard, Canchel), when user close application
+// Shows exit dialog (Save, Discard, Cancel), when user close application
 bool MainWindow::showExitDialog() {
      QMessageBox msgBox;
      msgBox.setText("The document has been modified.");
